# Probing by chirps

Livio's and also Henriette's idea that chrips may be employed by *Apterontus leptorhynchus* to probe for the presence of another fish. Henriette's idea goes one step further and suggests that the chrip might be used to get the sign of the beat, i.e. whether the communication partner is above or below the chirper's EOD frequency.

Livio's idea is that chirps (maybe also the different kinds of chirps) may be used to estimate whether there is another fish at all.

The code for this project can be found [here](https://whale.am28.uni-tuebingen.de/git/jgrewe/chirp_probing).

## Can we test Livio's hypothesis in P-units?

We can easily record the responses to foreign-generated chirps but we are not able to record in a situation in which the recorded fish itself chirps.

## Stimulus situation differs for self- and foreign generated chrips

The stimulus situation is remarkedly different for self- chirping as compared to the situation in which the other fish chirps. While the AM induced by the presence and the chriping activity of a foreign fish depends strongly on the distance between the communication partners (i.e. the contrast), self-chirping will always affect the input to the own electroreceptors. In the extreme, i.e. when chriping alone the AM is just the amplitude dip during the chirp. 

![](figures/chirp_induced_ams.png)

## P-unit simulations

We can still use simulations to test this idea using a P-unit model that was recently improved by a Master student in our Lab (Alexander Ott). In brief, the model is a Leaky-Integrate-And-Fire neuron that contains an spike induced adaptation current and a refractory period. The code can be found in the **model.py** python script and is also available form our [gitub repository](https://github.com/bendalab/punitmodel). This model is driven by a signal that is the self-generated EOD + the foreign signal.

The model more or less accurately reproduces the baseline features of cells that were recorded in the lab. It is fitted to resemble the real cell with resect to the baseline firing rate, the coefficient of variation of the baseline interspike interval histogram, the vector strength and the the FI-curve, i.e. the neuron's sensitivity to a driving stimulus, the minimum as well as maximum firing rates, and the adaptation time-constant.
We have used such models also to recreate the responses to white-noise stimulation.

P-units will still be driven by the amplitude change during the self chriping even if no other fish is present (soliloquy). The following figure shows this for a beat of 20 Hz, a chirp size of 100 Hz and an chirp induced amplitude dip of 5% for one example cell. The figure shows three conditions, chirping while nobody is around **soliloquy**, chirping while someone else is present **self chirping**, and there is another fish and the other fish is chriping **other chirping**. Top: illustration of the overall condition, second row, the combined signal of self-generated EOD and the foreign EOD. Red line is the AM. The remaining rows show the firing rate as a function of time. PSTHs are estimated using kernel convolution with a Gaussian kernel of 0.5ms standard deviation. Black lines are the averages across trials (n=25) and the gray area depicts the across trial variability, i.e. the standard deviation of the firing rates across trials. *C-values* on the right are the contrasts, i.e. the strength of the foreign fish's EOD relative to the own EOD. The orange fish is the recorded fish, the EOD-frequency matches the one of fish in which we recorded the respective P-unit.

![](figures/cell_2010-11-08-al-invivo-1_df_20Hz.png) 

## Foreign fish detection

To test whether the presence of a foreign fish can be better detected with chrips than without chirps I did a ROC analysis based on distributions of distances defined as the Euclidian dinstance between the P-unit responses in various phases of the responses. The responses are again the firing rates estimated using kernel convolution with a Gaussian kernel. Kernel standard deviations are a free parameter in the analysis.
The following comparisons are done. ![](figures/comparisons.png)

**1.** Can I distinguish the responses to the beat, i.e. the other fish is present, from the baseline responses when the recorded fish is alone? (**beat** comparison)

**2.** Is the response to the self-generated chirp in company distinguishable from the response to the self-generated while being alone? (**self vs soliloquy** comparison)

**3.** Is the response to the foreign generated chrip distinguishable from the response to the beat alone? (**other vs quietness** comparison)

### ROC analysis example cell

The figure shows the results from the ROC analysis from one example cell. The rows are the comparisons (s.o.). The left column are the roc curves for all tested contrasts, it plots the rates of true positives (correct classification) against the rate of false positive (wrong classifications). If responses are indistinguishable, the curve should follow the dashed identity line. Colors show ROC curves estimated at different beat frequencies. From the ROC curve the area under the curve (**auc**) is plotted in the right column as a function of the contrast. The temporal resolution of the distance estimation is set by the Gaussian kernel used to estimate the firing rates and its standard deviation is set to 1ms for the ROC curves on the left. The temporal resolution has a strong impact on the discrimination performance. This is shown in the right column. (sigma is the standard deviation of the kernel, i.e. the temporal resolution)
 
![](figures/roc_analysis.png)

### ROC analysis across cells and dfs

The figure below shows the discrimination performance as a function of the difference frequency and the contrast averaged over 10 simulated P-units. The rows are the comparison tasks the plots in the right column plot sections across the surfaces shown on the left. The error bars are the standard deviations across cells. Colormap is limited to 0.5, i.e. chance level.
**Note:** The frequency excursion of the chirp is 100Hz and a temporal resolution of the 1.0ms.


![](figures/discrimination_performances.png)

Basically, the detection of a foreign fish's presence is easily done on the basis of the beat. It depends on the contrast, naturally, and saturates at alost perfect perfromance at high contrasts and low beats. The performance in this task  directly depends on the  Signal-To-Noise ratio and thus directly reflects the beat tunig curve. Good discriminability is is possible for "small" difference frequencies. At +- 200Hz discrimination is not possible on the basis of the beat response.

When we compare the self-chirping when no other animal is present it first of all seems that the overall performance is worse. There are however a few interesting effects:
* it appears that detection of a foreigh fish extends to higher positive difference frequencies.
* the detection performance in slow beats the performace seems to increase faster with contrast.

Foreign fish detection using the responses while the other fish chirps seems to be much harder, we do see of performance for high frequency beats which the drops to chance level in places, the beat tuning is high. Overall low performance might be due to the chirp size which is 100Hz in this graph (more simulations with 40 and 60 Hz are running right now) and induces almost a 360 degree  phase shifts in low beats (needs confirmation).